@@ -312,7 +312,7 @@ def axis_angles_from_matrices(Rs, traces=None, out=None):
     out[..., 2] = Rs[..., 1, 0] - Rs[..., 0, 1]
 
     # The threshold is a result from this discussion:
-    # https://github.com/rock-learning/pytransform3d/issues/43
+    # https://github.com/dfki-ric/pytransform3d/issues/43
     # The standard formula becomes numerically unstable, however,
     # Rodrigues' formula reduces to R = I + 2 (ee^T - I), with the
     # rotation axis e, that is, ee^T = 0.5 * (R + I) and we can find the
@@ -691,9 +691,17 @@ def smooth_quaternion_trajectory(Q, start_component_positive="x"):
     -------
     Q : array, shape (n_steps, 4)
         Unit quaternions to represent rotations: (w, x, y, z)
+
+    Raises
+    ------
+    ValueError
+        If Q has length 0.
     """
     Q = np.copy(Q)
 
+    if len(Q) == 0:
+        raise ValueError("At least one quaternion is expected.")
+
     if Q[0, "wxyz".index(start_component_positive)] < 0.0:
         Q[0] *= -1.0
 
