@@ -2,7 +2,6 @@
 import numpy as np
 from numpy.testing import assert_array_almost_equal
 from ._utils import norm_axis_angle, norm_compact_axis_angle
-from ._conversions import matrix_from_euler_zyx, matrix_from_euler_xyz
 
 
 def assert_axis_angle_equal(a1, a2, *args, **kwargs):
@@ -102,64 +101,6 @@ def assert_quaternion_equal(q1, q2, *args, **kwargs):
         assert_array_almost_equal(q1, -q2, *args, **kwargs)
 
 
-def assert_euler_xyz_equal(e_xyz1, e_xyz2, *args, **kwargs):
-    """Raise an assertion if two xyz Euler angles are not approximately equal.
-
-    Note that Euler angles are only unique if we limit them to the intervals
-    [-pi, pi], [-pi/2, pi/2], and [-pi, pi] respectively. See
-    numpy.testing.assert_array_almost_equal for a more detailed documentation
-    of the other parameters.
-
-    Parameters
-    ----------
-    e_xyz1 : array-like, shape (3,)
-        Angles for rotation around x-, y'-, and z''-axes (intrinsic rotations)
-
-    e_xyz2 : array-like, shape (3,)
-        Angles for rotation around x-, y'-, and z''-axes (intrinsic rotations)
-
-    args : tuple
-        Positional arguments that will be passed to
-        `assert_array_almost_equal`
-
-    kwargs : dict
-        Positional arguments that will be passed to
-        `assert_array_almost_equal`
-    """
-    R1 = matrix_from_euler_xyz(e_xyz1)
-    R2 = matrix_from_euler_xyz(e_xyz2)
-    assert_array_almost_equal(R1, R2, *args, **kwargs)
-
-
-def assert_euler_zyx_equal(e_zyx1, e_zyx2, *args, **kwargs):
-    """Raise an assertion if two zyx Euler angles are not approximately equal.
-
-    Note that Euler angles are only unique if we limit them to the intervals
-    [-pi, pi], [-pi/2, pi/2], and [-pi, pi] respectively. See
-    numpy.testing.assert_array_almost_equal for a more detailed documentation
-    of the other parameters.
-
-    Parameters
-    ----------
-    e_zyx1 : array-like, shape (3,)
-        Angles for rotation around z-, y'-, and x''-axes (intrinsic rotations)
-
-    e_zyx2 : array-like, shape (3,)
-        Angles for rotation around z-, y'-, and x''-axes (intrinsic rotations)
-
-    args : tuple
-        Positional arguments that will be passed to
-        `assert_array_almost_equal`
-
-    kwargs : dict
-        Positional arguments that will be passed to
-        `assert_array_almost_equal`
-    """
-    R1 = matrix_from_euler_zyx(e_zyx1)
-    R2 = matrix_from_euler_zyx(e_zyx2)
-    assert_array_almost_equal(R1, R2, *args, **kwargs)
-
-
 def assert_rotation_matrix(R, *args, **kwargs):
     """Raise an assertion if a matrix is not a rotation matrix.
 
